@@ -98,6 +98,7 @@ Plot figure ...
 
 import math
 import sys
+import warnings
 
 from typing import Callable  # python >= 3.5
 
@@ -114,17 +115,20 @@ except ImportError:
     print("Vous devez installer le module ac-electricity pour tracer \
 les diagrammes de Bode")
 
+warnings.simplefilter('default', UserWarning)
+
 """ historique des versions
+0.3.8 : add warnings 2022-01
 0.3.7 : 2022-01
 0.0.1 : initial release 2021-11
 """
 
-__version__ = (0, 3, 7)
+__version__ = (0, 3, 8)
 __author__ = "Fabrice Sincère <fabrice.sincere@ac-grenoble.fr>"
 
 
 if sys.version_info[0] < 3:
-    print('You need to run this with Python 3')
+    print('You need to run this with Python >= 3')
     exit(1)
 
 
@@ -242,7 +246,7 @@ Exemple :
 20.0
 """
         # getter
-        return 20*math.log10(self.__A)
+        return 20*math.log10(abs(self.__A))
 
     def frequence_propre(self) -> float:
         """ Retourne la fréquence propre (en hertz)
@@ -544,6 +548,7 @@ coeff_amortissement=0.16, w0=10000))
             # approximation (car la précision de la formule
             # théorique se dégrade quand m augmente)
             # développement limité
+            warnings.warn('Valeur approchée avec une bonne approximation')
             return w0/(2*math.pi)/math.sqrt(2*(2*m*m-1))
 
     @staticmethod
@@ -563,6 +568,7 @@ facteur_resonance_db=20))
         if facteur_resonance_db > 1000:
             # TODO :
             # développement limité
+            warnings.warn('Valeur attendue très proche de 0')
             return 0.0
 
         # résolution à partir de la fonction inverse
@@ -597,9 +603,11 @@ facteur de résonance : 10.0125234864... ou 20.010870956... dB
         if m < 0:
             raise ValueError("Le coefficient d'amortissement doit être positif")
         if m == 0:
+            warnings.warn('Résonance infinie')
             return math.inf, math.inf  # python >= 3.5
         elif m >= 1/math.sqrt(2):
             # pas de résonance harmonique
+            warnings.warn('Pas de résonance')
             return 1, 0
         else:
             f = 1/(2*m*math.sqrt(1-m*m))
@@ -627,6 +635,7 @@ coeff_amortissement=0.16, frequence_resonance=1550.27))
 
         if m >= 1/math.sqrt(2):
             # pas de résonance harmonique
+            warnings.warn('Pas de résonance')
             return 0
         else:
             return fr*(2*math.pi)/math.sqrt(1-2*m*m)
@@ -652,6 +661,7 @@ coeff_amortissement=0.16, w0=10000))
 
         if m >= 1/math.sqrt(2):
             # pas de résonance harmonique
+            warnings.warn('Pas de résonance')
             return 0
         else:
             return w0*math.sqrt(1-2*m*m)/(2*math.pi)
@@ -679,6 +689,7 @@ positif")
         p = pourcentage*0.01
         if p == 0:
             # infini
+            warnings.warn('Temps de réponse infini')
             return math.inf  # python >= 3.5
         elif p == 1:
             return 0
@@ -688,6 +699,7 @@ entre 0 et 100 %")
 
         if m == 0:
             # régime oscillant
+            warnings.warn('Temps de réponse infini')
             return math.inf  # python >= 3.5
         elif 0 < m < 1:
             # régime pseudo-périodique
@@ -1026,7 +1038,7 @@ Exemple :
 """
     # autre solution : module Scipy...
     if (f(a)-y0)*(f(b)-y0) > 0:
-        raise ValueError("Problème de convergence")
+        raise ValueError("Mauvais intervalle de recherche")
     compteur = 0
     while ((abs(a-b) if a == 0 else abs((a-b)/a))) > abs(eps):
         c = (a+b)/2
